package com.atguigu.ssyx.acl.controller;

import com.atguigu.ssyx.acl.service.AdminService;
import com.atguigu.ssyx.acl.service.RoleService;
import com.atguigu.ssyx.common.result.Result;
import com.atguigu.ssyx.model.acl.Admin;
import com.atguigu.ssyx.vo.acl.AdminQueryVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/admin/acl/user")
@Api(tags = "用户管理")
public class AdminController {
    @Autowired
    private AdminService adminService;
    @Autowired
    private RoleService roleService;

    @ApiOperation(value = "获取管理用户分页列表")
    @GetMapping("{page}/{limit}")
    public Result<IPage<Admin>> index(
            @ApiParam(name = "page", value = "当前页码", required = true)
            @PathVariable Long page,

            @ApiParam(name = "limit", value = "每页记录数", required = true)
            @PathVariable Long limit,

            @ApiParam(name = "userQueryVo", value = "查询对象")
            AdminQueryVo userQueryVo
    ) {
        IPage<Admin> pageModel = adminService.selectPage(page, limit, userQueryVo);
        return Result.success(pageModel);
    }

    @ApiOperation(value = "获取管理用户")
    @GetMapping("get/{id}")
    public Result<Admin> get(@PathVariable Long id) {
        Admin admin = adminService.getById(id);
        return Result.success(admin);
    }

    @ApiOperation(value = "新增管理用户")
    @PostMapping("save")
    public Result<Admin> save(@RequestBody Admin admin) {
        boolean isSuccess = adminService.saveByAdmin(admin);
        return isSuccess ? Result.success() : Result.error();
    }

    @ApiOperation(value = "修改管理用户")
    @PutMapping("update")
    public Result<Admin> updateById(@RequestBody Admin admin) {
        adminService.updateById(admin);
        return Result.success();
    }

    @ApiOperation(value = "删除管理用户")
    @DeleteMapping("remove/{id}")
    public Result<Admin> remove(@PathVariable Long id) {
        adminService.removeById(id);
        return Result.success();
    }

    @ApiOperation(value = "根据id列表删除管理用户")
    @DeleteMapping("batchRemove")
    public Result<List<Long>> batchRemove(@RequestBody List<Long> ids) {
        adminService.removeByIds(ids);
        return Result.success();
    }
}